@@ -8,7 +8,7 @@ import numpy as np
 from .utils import readToGray
 from .utils import saveNumpy
 
-def preprocess(DIR, classes, name, resized_size=224, train_size=None, isShuffle=True, isSave = True):
+def preprocess(DIR, classes, name, resized_size=224, train_size=None, isNormalize=False, isShuffle=True, isSave = True):
     """
     Reads Images in base directory DIR
     Returns
@@ -52,7 +52,10 @@ def preprocess(DIR, classes, name, resized_size=224, train_size=None, isShuffle=
 
                         # Returns image RESIZED and GRAY
                         gray = readToGray(image_path, resized_size)
-
+                        # Normalizing
+                        if isNormalize is True:
+                            gray = normalize(gray)
+                            
                         train.append([gray, classNum])
                         count +=1 
                         _printTotal(count, item)
