@@ -4,7 +4,6 @@
 # Importing the necessary packages
 # import os
 from urllib.request import urlopen
-import time
 import cv2 as cv
 import numpy as np
 
@@ -33,11 +32,12 @@ def saveNumpy(name, x):
     Saves an array to a .npy file
     Converts to Numpy (if not already)
     """
-    since = time.time()
+
     x = np.array(x)
-    np.save(name, x)
-    end = time.time()
-    print(f'Took {end-since}s to save')
+    if '.npy' in name:
+        np.save(name, x)
+    elif '.npz' in name:
+        np.savez_compressed(name, x)
 
 def train_val_split(X,y,val_ratio=.2):
     """
